------------------Namespace------------------
local _, core = ...
core.HotT = {}

local Hott = core.HotT

------------------Variables------------------

local maxItemlevel = 35
local characterLevel = 30
local currentZone = GetMinimapZoneText()
local deffCDs = {
                    47788,  -- Guardian
                    116849, -- LifeCocoon
                    871,    -- Schildwall
                    102342  -- Ironbark
                }

------------------Functions------------------

local function Gear_Check_Self()
    local wrongItemsCount = 0
    for i=1,18 do
        --If not shirt or tabard slot...
            if (i ~= 4 and i ~= 19) then
            -- Get Item ID for inventory slot
                local itemLink = GetInventoryItemLink("PLAYER", i)
                if (itemLink) then
                -- Get item level for piece in slot
                local effectiveILvl, isPreview, baseILvl = GetDetailedItemLevelInfo(itemLink)
                -- print(effectiveILvl .. "    Itemslot: " .. i)
                -- Compare item level to maxItemLevel
                    if (effectiveILvl > maxItemlevel) then
                        wrongItemsCount = wrongItemsCount + 1
                    end
                end
            end
        end
    return wrongItemsCount
end

local function Gear_Check_Customer()
    local wrongItemsCount = 0
    local customerNames = "" --with wrong Gear
    for k=1, GetNumGroupMembers() do
        raidId = "raid".. k
        if UnitExists(raidId) and not UnitIsDead(raidId) and UnitIsConnected(raidId) then
            if (UnitLevel(raidId) == characterLevel) then
                for i=1,18 do
                    --If not shirt or tabard slot...
                    if (i ~= 4 and i ~= 19) then
                        -- Get Item ID for inventory slot
                        local itemLink = GetInventoryItemLink(raidId, i)
                        if (itemLink) then
                            -- Get item level for piece in slot
                            local effectiveILvl, isPreview, baseILvl = GetDetailedItemLevelInfo(itemLink)
                            -- print(effectiveILvl .. "    Itemslot: " .. i)
                            -- Compare item level to maxItemLevel
                            if (effectiveILvl > maxItemlevel) then
                                wrongItemsCount = wrongItemsCount + 1
                            end
                        end
                    end
                end
                if (wrongItemsCount > 0) then
                    customerNames = customerNames .. raidId .. "´s "
                end
                wrongItemsCount = 0
            end
        end
    end
    return customerNames
end

local function Get_Spark_Life()
    local lowestLife = 0
    local percentageLife = 0
    for i=1,10 do
        local nameplateUnit = "nameplate"..i 
        if (UnitExists(nameplateUnit) and UnitIsVisible(nameplateUnit)) then
            local guid = UnitGUID(nameplateUnit)
            local type, zero, server_id, instance_id, zone_uid, npc_id, spawn_uid = strsplit("-",guid)
            if (tonumber(npc_id)==32955) then
                if (UnitIsDead(nameplateUnit) == false and UnitHealth(nameplateUnit) > 1) then
                    if (lowestLife > UnitHealth(nameplateUnit) or lowestLife == 0) then
                        lowestLife = UnitHealth(nameplateUnit)
                    end
                end
                percentageLife =  math.floor((lowestLife / UnitHealthMax(nameplateUnit)) * 100)
            end
        end  
    end
    for i=1,40 do
    local raidTarget = "raid"..i.."target"
        if (UnitExists(raidTarget)) then
            local guid = UnitGUID(raidTarget)
            local type, zero, server_id, instance_id, zone_uid, npc_id, spawn_uid = strsplit("-",guid)
            if (tonumber(npc_id)==32955) then
                if (UnitIsDead(raidTarget)==false) then
                    if (lowestLife > UnitHealth(raidTarget) or lowestLife == 0) then
                        lowestLife = UnitHealth(raidTarget)
                    end   
                end
            end
            percentageLife =  math.floor((lowestLife / UnitHealthMax(raidTarget)) * 100)
        end  
    end
    return percentageLife
end

local function Check_Customer_Combat()
    local playersNotinCombat= ""
    if (UnitExists("player")) then 
        for i=1,40 do
            local raidMember = "raid"..i
            if (UnitExists(raidMember)) then
                if (UnitAffectingCombat(raidMember)==false) then
                    playersNotinCombat = playersNotinCombat .. raidMember .. " "
                    print(playersNotinCombat)
                end
            end
        end
    end
end

--------------------Frames--------------------

local selfCheck = CreateFrame("Frame", nil, UIParent)
selfCheck.text = selfCheck:CreateFontString(nil, "ARTWORK")
selfCheck.text:SetFont("Fonts\\ARIALN.ttf", 30, "OUTLINE")
selfCheck.text:SetText("Check Your Gear!")
selfCheck.text:SetPoint("CENTER", 0, 150)
selfCheck:SetSize(300,360)
selfCheck:SetPoint("Center", UIParent, "Center")
selfCheck:RegisterEvent("UNIT_INVENTORY_CHANGED")
selfCheck:RegisterEvent("PLAYER_ENTERING_WORLD")
selfCheck:SetScript("OnEvent", function(self, event, ...)
    if (UnitLevel("PLAYER") == characterLevel) then
        if (Gear_Check_Self() > 0) then
            selfCheck:Show()
        else
            selfCheck:Hide()
        end
    else
        selfCheck:Hide()
    end
end)


local customerCheck = CreateFrame("Frame", nil, UIParent)
customerCheck.text = customerCheck:CreateFontString(nil, "ARTWORK")
customerCheck.text:SetFont("Fonts\\ARIALN.ttf", 30, "OUTLINE")
customerCheck.text:SetPoint("CENTER", 0, 150)
customerCheck:SetSize(300,360)
customerCheck:SetPoint("Center", UIParent, "Center")
customerCheck:RegisterEvent("GROUP_ROSTER_UPDATE")
customerCheck:SetScript("OnEvent", function(self, event, ...)
    if (UnitLevel("PLAYER") == characterLevel) then
        if (UnitLevel("PLAYER") == characterLevel) then
            customerNames = Gear_Check_Customer()
            if (customerNames ~= "") then
                customerCheck:Show()
                customerCheck.text:SetText("Check " .. customerNames .. "Gear!")
            else
                customerCheck:Hide()
            end
        end
    end
end)

local CastbarBackground = CreateFrame("Frame", nil, UIParent ,BackdropTemplateMixin and "BackdropTemplate")
CastbarBackground:SetPoint("RIGHT", -900, 175)
CastbarBackground:SetSize(300, 50)
CastbarBackground:Hide()
CastbarBackground:SetBackdrop({
    bgFile = "Interface/Tooltips/UI-Tooltip-Background",
    edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
    edgeSize = 0.5,
    insets = { left = 0, right = 0, top = 0, bottom = 0 },
})
CastbarBackground:SetBackdropColor(0,0,0,0.8)

local CastBar = CreateFrame("Frame", nil, UIParent ,BackdropTemplateMixin and "BackdropTemplate")
CastBar:SetPoint("LEFT", 900, 175)
CastBar:SetSize(300, 50)
CastBar:Hide()
CastBar:SetBackdrop({
    bgFile = "Interface/Tooltips/UI-Tooltip-Background",
    edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
    edgeSize = 0.5,
    insets = { left = 0, right = 0, top = 0, bottom = 0 },
})
CastBar:SetBackdropColor(1,0,0,1)

local CastTime = CreateFrame("Frame", nil, UIParent)
CastTime.text = CastTime:CreateFontString(nil, "ARTWORK")
CastTime.text:SetFont("Fonts\\ARIALN.ttf", 30, "OUTLINE")
CastTime.text:SetPoint("CENTER", 0, 175)
CastTime:SetSize(300,50)
CastTime:Hide()
CastTime:SetPoint("Center", UIParent, "Center")

local castIcon1 = CreateFrame("Frame", nil, UIParent ,BackdropTemplateMixin and "BackdropTemplate")
castIcon1:SetPoint("CENTER", -175, 175)
castIcon1:SetSize(50, 50)
castIcon1:Hide()

local castIcon2 = CreateFrame("Frame", nil, UIParent ,BackdropTemplateMixin and "BackdropTemplate")
castIcon2:SetPoint("CENTER", 175, 175)
castIcon2:SetSize(50, 50)
castIcon2:Hide()

local deffCDIcon = CreateFrame("Frame", nil, UIParent ,BackdropTemplateMixin and "BackdropTemplate")
deffCDIcon:SetPoint("CENTER", -175, 100)
deffCDIcon:SetSize(60, 60)
deffCDIcon:Hide()

local deffCDTimer = CreateFrame("Frame", nil, UIParent)
deffCDTimer.text = deffCDTimer:CreateFontString(nil, "ARTWORK")
deffCDTimer.text:SetFont("Fonts\\ARIALN.ttf", 40, "OUTLINE")
deffCDTimer.text:SetPoint("CENTER", -175, 100)
deffCDTimer:SetSize(300,50)
deffCDTimer:Hide()
deffCDTimer:SetPoint("Center", UIParent, "Center")

local deffCDTarget = CreateFrame("Frame", nil, UIParent)
deffCDTarget.text = deffCDTarget:CreateFontString(nil, "ARTWORK")
deffCDTarget.text:SetFont("Fonts\\ARIALN.ttf", 30, "OUTLINE")
deffCDTarget.text:SetPoint("CENTER", -175, 50)
deffCDTarget:SetSize(300,50)
deffCDTarget:Hide()
deffCDTarget:SetPoint("Center", UIParent, "Center")

local castEvent = CreateFrame('Frame')
castEvent:SetScript('OnUpdate', function(self, elapsed)
    Check_Customer_Combat()
    local name, text, icon, startTimeMS, endTimeMS, isTradeSkill, castID, notInterruptible, spellId = UnitCastingInfo("boss1")
    if (spellId) then
        local currentCasttime = GetTime() - startTimeMS/1000
        local castMapping = 300*1000/(endTimeMS-startTimeMS)
        if (currentCasttime > 0) then
            CastTime:Show()
            CastTime.text:SetText(name)
            CastBar:Show()
            CastBar:SetSize(castMapping*currentCasttime, 50)
            CastbarBackground:Show()
            CastbarBackground:SetSize(300-castMapping*currentCasttime, 50)
            castIcon1:Show()
            castIcon1:SetBackdrop({
                bgFile = icon,
                edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
                edgeSize = 0.5,
            })
            castIcon2:Show()
            castIcon2:SetBackdrop({
                bgFile = icon,
            })
        end
    else
        CastbarBackground:Hide()
        CastBar:Hide()
        CastTime:Hide()  
        castIcon1:Hide()
        castIcon2:Hide()  
    end 
end)

local buffEvent = CreateFrame("Frame")
castEvent:SetScript("OnUpdate", function(self, elapsed)
    local iconsyombol = 0
    local buffTime = 0
    local buffTarget= ""
    local breakFlag = false -- idk how to solve it proberly
    for i=1,40 do
        local raidMember = "raid"..i
        --local raidMember = "player"
        if (UnitExists(raidMember)) then
            if (UnitGroupRolesAssigned(raidMember)==TANK) then
                for l=1,40 do
                    name, icon, count, debuffType, duration, expirationTime, source, isStealable, nameplateShowPersonal, spellId, canApplyAura, isBossDebuff, castByPlayer, nameplateShowAll, timeMod= UnitAura(raidMember , l, "HELPFUL")
                    if breakFlag == false then
                        if(spellId) then
                            for k=1,table.getn(deffCDs) do
                                if (spellId == deffCDs[k]) then
                                    iconsyombol = icon
                                    buffTarget = UnitName(raidMember)
                                    buffTime = math.floor(expirationTime-GetTime())
                                    breakFlag = true
                                    break 
                                else
                                    iconsyombol = 0
                                end
                            end
                        end
                    else
                        break
                    end
                end
            end
        else
            breakFlag = false
            break    
        end
    end
    if iconsyombol > 0 then
        deffCDIcon:Show()
            deffCDIcon:SetBackdrop({
            bgFile = iconsyombol,
            edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
            edgeSize = 0.5,
        })
        deffCDTarget:Show()
        deffCDTarget.text:SetText(buffTarget)
        deffCDTimer:Show()
        deffCDTimer.text:SetText(buffTime)
    else
        deffCDTarget:Hide()
        deffCDTimer:Hide()
        deffCDIcon:Hide()  
    end
end)

local sparkLifeBackground = CreateFrame("Frame", nil, UIParent ,BackdropTemplateMixin and "BackdropTemplate")
sparkLifeBackground:SetPoint("RIGHT", -900, 250)
sparkLifeBackground:SetSize(300,50)
sparkLifeBackground:Hide()
sparkLifeBackground:SetBackdrop({
    bgFile = "Interface/Tooltips/UI-Tooltip-Background",
    edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
    edgeSize = 0.5,
    insets = { left = 0, right = 0, top = 0, bottom = 0 },
})
sparkLifeBackground:SetBackdropColor(0,0,0,0.8)

local sparkLife = CreateFrame("Frame", nil, UIParent ,BackdropTemplateMixin and "BackdropTemplate")
sparkLife:SetPoint("LEFT", 900, 250)
sparkLife:SetSize(300, 50)
sparkLife:Hide()
sparkLife:SetBackdrop({
    bgFile = "Interface/Tooltips/UI-Tooltip-Background",
    edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
    edgeSize = 0.5,
    insets = { left = 0, right = 0, top = 0, bottom = 0 },
})
sparkLife:SetBackdropColor(0,1,0,1)

local sparkLifeText = CreateFrame("Frame", nil, UIParent)
sparkLifeText.text = sparkLifeText:CreateFontString(nil, "ARTWORK")
sparkLifeText.text:SetFont("Fonts\\ARIALN.ttf", 30, "OUTLINE")
sparkLifeText.text:SetPoint("CENTER", 0, 250)
sparkLifeText:SetSize(300,50)
sparkLifeText:Hide()
sparkLifeText:SetPoint("Center", UIParent, "Center")
sparkLifeText:RegisterEvent("PLAYER_TARGET_CHANGED")
sparkLifeText:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
sparkLifeText:SetScript("OnEvent", function(self, event, ...)
    if (currentZone == "Das Himmlische Planetarium" ) then
        local currentLife = Get_Spark_Life()
        if (currentLife > 0) then
            sparkLifeText:Show()
            sparkLifeText.text:SetText(currentLife .."%")
            sparkLife:Show()
            sparkLife:SetSize(currentLife*3,50)
            if (currentLife == 100) then
                sparkLifeBackground:Hide()
            else
                sparkLifeBackground:Show()
                sparkLifeBackground:SetSize(300-(currentLife*3),50)
            end
        else
            sparkLifeText:Hide()
            sparkLife:Hide()
            sparkLifeBackground:Hide()
        end
    end
end)

local CautionText = CreateFrame("Frame", nil, UIParent)
CautionText.text = CautionText:CreateFontString(nil, "ARTWORK")
CautionText.text:SetFont("Fonts\\ARIALN.ttf", 30, "OUTLINE")
CautionText.text:SetPoint("CENTER", 0, 50)
CautionText:SetSize(300,50)
CautionText.text:SetText("Phasetransition")
CautionText:Hide()
CautionText:SetPoint("Center", UIParent, "Center")
CautionText:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
CautionText:RegisterEvent("PLAYER_TARGET_CHANGED")
CautionText:SetScript("OnEvent", function(self, event, ...)
    if (currentZone == "Das Himmlische Planetarium" ) then
        if (UnitExists("boss1")) then
            local percentageLifeBoss =  math.floor((UnitHealth("boss1") / UnitHealthMax("boss1")) * 100)
            if(percentageLifeBoss < 25 and percentageLifeBoss > 19) then
                CautionText:Show()
            else
                CautionText:Hide()
            end
        else
            CautionText:Hide()
        end
    end
end)



local AddonLoading = CreateFrame("Frame", nil, UIParent)
AddonLoading:SetPoint("CENTER", 0, 0)
AddonLoading:SetSize(300, 350)
AddonLoading:RegisterEvent("ZONE_CHANGED_INDOORS")
AddonLoading:RegisterEvent("PLAYER_ENTERING_WORLD")
AddonLoading:SetScript("OnEvent", function(self, event, ...)
    currentZone = GetMinimapZoneText()    
end)

print("Hott loading")
